@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 __author__ = "Mikhail Fedosov (tbs.micle@gmail.com)"
-__version__ = "0.1.3.5"
+__version__ = "0.1.3.6"
 
 # http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/
 # http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python
@@ -89,13 +89,12 @@ def main():
 		map(check_package, pip.get_installed_distributions())
 	else:
 		pypi_pool = Pool()
+		pypi_pool_map = pypi_pool.map_async(check_package, pip.get_installed_distributions())
 		try:
-			pypi_pool.map(check_package, pip.get_installed_distributions())
-			pypi_pool.close()
-			pypi_pool.join()
+			pypi_pool_map.get(0xFFFF)
 		except KeyboardInterrupt:
 			print("Aborted")
-			pypi_pool.terminate()
+			return
 
 if __name__ == "__main__":
 	main()
\ No newline at end of file
